.. radarSat2_xarray_reader documentation master file, created by
   sphinx-quickstart on Wed Oct 26 10:20:56 2022.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to xradarSat2 documentation!
=================================================

.. automodule:: radarSat2_xarray_reader


.. toctree::
   :maxdepth: 2
   :caption: Contents:

   modules
   Installation

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
